@@ -4,7 +4,8 @@
 def _checkSample(testcase, installed):
     try:
         import pkg_resources
-    except ImportError: # no setuptools :(
+    except ImportError: # pragma: NO COVER
+        # no setuptools :(
         pass
     else:
         version = pkg_resources.require('pkginfo')[0].version
@@ -20,7 +21,6 @@ def _checkClassifiers(testcase, installed):
       'Intended Audience :: Developers',
       'License :: OSI Approved :: MIT License',
       'Operating System :: OS Independent',
-      'Programming Language :: Python :: 2.7',
       'Programming Language :: Python :: 3.6',
       'Programming Language :: Python :: 3.7',
       'Programming Language :: Python :: 3.8',
